@@ -1,28 +1,29 @@
 """Patito, a data-modelling library built on top of polars and pydantic."""
-import pkg_resources
-from pkg_resources import DistributionNotFound
 from polars import Expr, Series, col
 
-from patito import exceptions
+from patito import exceptions, sql
 from patito.exceptions import ValidationError
-from patito.polars import DataFrame
+from patito.polars import DataFrame, LazyFrame
 from patito.pydantic import Field, Model
 
 _DUCKDB_AVAILABLE = False
+field = col("_")
 __all__ = [
     "DataFrame",
     "Expr",
     "Field",
+    "LazyFrame",
     "Model",
     "Series",
     "ValidationError",
+    "_DUCKDB_AVAILABLE",
     "col",
     "exceptions",
-    "_DUCKDB_AVAILABLE",
+    "field",
+    "sql",
 ]
 
 try:
-    pkg_resources.require(["duckdb>=0.3.2"])
     from patito.duckdb import Database, Relation, RelationSource
 
     _DUCKDB_AVAILABLE = True
@@ -31,12 +32,12 @@ try:
         "Relation",
         "RelationSource",
     ]
-except DistributionNotFound:  # pragma: no cover
+except ImportError:  # pragma: no cover
     pass
 
 
 try:
-    from importlib.metadata import PackageNotFoundError, version  # type: ignore
+    from importlib.metadata import PackageNotFoundError, version
 except ImportError:  # pragma: no cover
     from importlib_metadata import PackageNotFoundError, version  # type: ignore
 
